@@ -5,16 +5,17 @@ use std::path::PathBuf;
 use std::process::ExitStatus;
 use std::sync::LazyLock;
 
+use crate::PythonRunnerOutput;
 use owo_colors::OwoColorize;
 use regex::Regex;
 use thiserror::Error;
 use tracing::error;
 use uv_configuration::BuildOutput;
+use uv_distribution_types::IsBuildBackendError;
 use uv_fs::Simplified;
 use uv_pep440::Version;
 use uv_pep508::PackageName;
-
-use crate::PythonRunnerOutput;
+use uv_types::AnyErrorBuild;
 
 /// e.g. `pygraphviz/graphviz_wrap.c:3020:10: fatal error: graphviz/cgraph.h: No such file or directory`
 static MISSING_HEADER_RE_GCC: LazyLock<Regex> = LazyLock::new(|| {
@@ -68,19 +69,47 @@ pub enum Error {
     #[error("Editable installs with setup.py legacy builds are unsupported, please specify a build backend in pyproject.toml")]
     EditableSetupPy,
     #[error("Failed to resolve requirements from {0}")]
-    RequirementsResolve(&'static str, #[source] anyhow::Error),
+    RequirementsResolve(&'static str, #[source] AnyErrorBuild),
     #[error("Failed to install requirements from {0}")]
-    RequirementsInstall(&'static str, #[source] anyhow::Error),
+    RequirementsInstall(&'static str, #[source] AnyErrorBuild),
     #[error("Failed to create temporary virtualenv")]
     Virtualenv(#[from] uv_virtualenv::Error),
+    // Build backend errors
     #[error("Failed to run `{0}`")]
     CommandFailed(PathBuf, #[source] io::Error),
-    #[error(transparent)]
+    #[error("The build backend returned an error")]
     BuildBackend(#[from] BuildBackendError),
-    #[error(transparent)]
+    #[error("The build backend returned an error")]
     MissingHeader(#[from] MissingHeaderError),
     #[error("Failed to build PATH for build script")]
     BuildScriptPath(#[source] env::JoinPathsError),
+    // For the convenience of typing `setup_build` properly.
+    #[error("Building source distributions for {0} is disabled")]
+    NoSourceDistBuild(PackageName),
+    #[error("Building source distributions is disabled")]
+    NoSourceDistBuilds,
+}
+
+impl IsBuildBackendError for Error {
+    fn is_build_backend_error(&self) -> bool {
+        match self {
+            Self::Io(_)
+            | Self::Lowering(_)
+            | Self::InvalidSourceDist(_)
+            | Self::InvalidPyprojectTomlSyntax(_)
+            | Self::InvalidPyprojectTomlSchema(_)
+            | Self::EditableSetupPy
+            | Self::RequirementsResolve(_, _)
+            | Self::RequirementsInstall(_, _)
+            | Self::Virtualenv(_)
+            | Self::NoSourceDistBuild(_)
+            | Self::NoSourceDistBuilds => false,
+            Self::CommandFailed(_, _)
+            | Self::BuildBackend(_)
+            | Self::MissingHeader(_)
+            | Self::BuildScriptPath(_) => true,
+        }
+    }
 }
 
 #[derive(Debug)]
@@ -247,6 +276,13 @@ impl Display for BuildBackendError {
             writeln!(f)?;
         }
 
+        write!(
+            f,
+            "\n{}{} This usually indicates a problem with the package or the build environment.",
+            "hint".bold().cyan(),
+            ":".bold()
+        )?;
+
         Ok(())
     }
 }
@@ -416,7 +452,10 @@ mod test {
 
         assert!(matches!(err, Error::MissingHeader { .. }));
         // Unix uses exit status, Windows uses exit code.
-        let formatted = err.to_string().replace("exit status: ", "exit code: ");
+        let formatted = std::error::Error::source(&err)
+            .unwrap()
+            .to_string()
+            .replace("exit status: ", "exit code: ");
         let formatted = anstream::adapter::strip_str(&formatted);
         insta::assert_snapshot!(formatted, @r###"
         Failed building wheel through setup.py (exit code: 0)
@@ -471,7 +510,10 @@ mod test {
         );
         assert!(matches!(err, Error::MissingHeader { .. }));
         // Unix uses exit status, Windows uses exit code.
-        let formatted = err.to_string().replace("exit status: ", "exit code: ");
+        let formatted = std::error::Error::source(&err)
+            .unwrap()
+            .to_string()
+            .replace("exit status: ", "exit code: ");
         let formatted = anstream::adapter::strip_str(&formatted);
         insta::assert_snapshot!(formatted, @r###"
         Failed building wheel through setup.py (exit code: 0)
@@ -516,7 +558,10 @@ mod test {
         );
         assert!(matches!(err, Error::MissingHeader { .. }));
         // Unix uses exit status, Windows uses exit code.
-        let formatted = err.to_string().replace("exit status: ", "exit code: ");
+        let formatted = std::error::Error::source(&err)
+            .unwrap()
+            .to_string()
+            .replace("exit status: ", "exit code: ");
         let formatted = anstream::adapter::strip_str(&formatted);
         insta::assert_snapshot!(formatted, @r###"
         Failed building wheel through setup.py (exit code: 0)
@@ -559,7 +604,10 @@ mod test {
         );
         assert!(matches!(err, Error::MissingHeader { .. }));
         // Unix uses exit status, Windows uses exit code.
-        let formatted = err.to_string().replace("exit status: ", "exit code: ");
+        let formatted = std::error::Error::source(&err)
+            .unwrap()
+            .to_string()
+            .replace("exit status: ", "exit code: ");
         let formatted = anstream::adapter::strip_str(&formatted);
         insta::assert_snapshot!(formatted, @r###"
         Failed building wheel through setup.py (exit code: 0)
