@@ -111,8 +111,8 @@ impl fmt::Display for EnvironmentNotFound {
     }
 }
 
-impl std::fmt::Display for InvalidEnvironment {
-    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
+impl fmt::Display for InvalidEnvironment {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         write!(
             f,
             "Invalid environment at `{}`: {}",
@@ -122,8 +122,8 @@ impl std::fmt::Display for InvalidEnvironment {
     }
 }
 
-impl std::fmt::Display for InvalidEnvironmentKind {
-    fn fmt(&self, f: &mut std::fmt::Formatter) -> std::fmt::Result {
+impl fmt::Display for InvalidEnvironmentKind {
+    fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         match self {
             Self::NotDirectory => write!(f, "expected directory but found a file"),
             Self::MissingExecutable(path) => {
