@@ -897,7 +897,9 @@ fn fail() -> Result<()> {
         from setuptools import setup
     IndentationError: unexpected indent
       × Failed to build `[TEMP_DIR]/project`
-      ╰─▶ Build backend failed to determine requirements with `build_sdist()` (exit status: 1)
+      ├─▶ The build backend returned an error
+      ╰─▶ Call to `setuptools.build_meta.build_sdist` failed (exit status: 1)
+          hint: This usually indicates a problem with the package or the build environment.
     "###);
 
     Ok(())
@@ -1345,7 +1347,9 @@ fn build_all_with_failure() -> Result<()> {
     Successfully built dist/member_a-0.1.0.tar.gz
     Successfully built dist/member_a-0.1.0-py3-none-any.whl
       × Failed to build `member-b @ [TEMP_DIR]/project/packages/member_b`
-      ╰─▶ Build backend failed to determine requirements with `build_sdist()` (exit status: 1)
+      ├─▶ The build backend returned an error
+      ╰─▶ Call to `setuptools.build_meta.build_sdist` failed (exit status: 1)
+          hint: This usually indicates a problem with the package or the build environment.
     Successfully built dist/project-0.1.0.tar.gz
     Successfully built dist/project-0.1.0-py3-none-any.whl
     "###);
